@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -44,6 +45,7 @@
 #include <cppuhelper/typeprovider.hxx>
 #include <tools/debug.hxx>
 #include <tools/diagnose_ex.h>
+#include <sal/macros.h>
 
 using namespace ::com::sun::star::sdbc;
 using namespace ::com::sun::star::sdbcx;
@@ -66,7 +68,6 @@ using namespace dbaccess;
 //============================================================
 IMPLEMENT_FORWARD_XINTERFACE2(OTableColumnDescriptor,OColumn,TXChild)
 
-//------------------------------------------------------------------------------
 void OTableColumnDescriptor::impl_registerProperties()
 {
     sal_Int32 nDefaultAttr = m_bActAsDescriptor ? 0 : PropertyAttribute::READONLY;
@@ -89,17 +90,14 @@ void OTableColumnDescriptor::impl_registerProperties()
     OColumnSettings::registerProperties( *this );
 }
 
-//--------------------------------------------------------------------------
 IMPLEMENT_GET_IMPLEMENTATION_ID( OTableColumnDescriptor )
 
 // ::com::sun::star::lang::XServiceInfo
-//------------------------------------------------------------------------------
 rtl::OUString OTableColumnDescriptor::getImplementationName(  ) throw (RuntimeException)
 {
-    return rtl::OUString::createFromAscii("com.sun.star.sdb.OTableColumnDescriptor");
+    return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.sdb.OTableColumnDescriptor"));
 }
 
-//------------------------------------------------------------------------------
 Sequence< ::rtl::OUString > OTableColumnDescriptor::getSupportedServiceNames(  ) throw (RuntimeException)
 {
     Sequence< ::rtl::OUString > aSNS( 2 );
@@ -109,7 +107,6 @@ Sequence< ::rtl::OUString > OTableColumnDescriptor::getSupportedServiceNames(  )
 }
 
 // comphelper::OPropertyArrayUsageHelper
-//------------------------------------------------------------------------------
 ::cppu::IPropertyArrayHelper* OTableColumnDescriptor::createArrayHelper( ) const
 {
     Sequence< Property > aProps;
@@ -118,26 +115,23 @@ Sequence< ::rtl::OUString > OTableColumnDescriptor::getSupportedServiceNames(  )
 }
 
 // cppu::OPropertySetHelper
-//------------------------------------------------------------------------------
 ::cppu::IPropertyArrayHelper& OTableColumnDescriptor::getInfoHelper()
 {
     return *static_cast< ::comphelper::OPropertyArrayUsageHelper< OTableColumnDescriptor >* >(this)->getArrayHelper();
 }
 
-//------------------------------------------------------------------------------
 void OTableColumnDescriptor::setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, const Any& rValue ) throw (Exception)
 {
     OColumn::setFastPropertyValue_NoBroadcast( nHandle, rValue );
     ::dbaccess::notifyDataSourceModified( m_xParent, sal_True );
 }
 
-// -----------------------------------------------------------------------------
 Reference< XInterface > SAL_CALL OTableColumnDescriptor::getParent(  ) throw (RuntimeException)
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     return m_xParent;
 }
-// -----------------------------------------------------------------------------
+
 void SAL_CALL OTableColumnDescriptor::setParent( const Reference< XInterface >& _xParent ) throw (NoSupportException, RuntimeException)
 {
     ::osl::MutexGuard aGuard(m_aMutex);
@@ -148,7 +142,6 @@ void SAL_CALL OTableColumnDescriptor::setParent( const Reference< XInterface >&
 //============================================================
 DBG_NAME(OTableColumn);
 
-// -------------------------------------------------------------------------
 OTableColumn::OTableColumn( const ::rtl::OUString& _rName )
     :OTableColumnDescriptor( false /* do not act as descriptor */ )
 {
@@ -156,28 +149,23 @@ OTableColumn::OTableColumn( const ::rtl::OUString& _rName )
     m_sName = _rName;
 }
 
-// -----------------------------------------------------------------------------
 OTableColumn::~OTableColumn()
 {
     DBG_DTOR(OTableColumn,NULL);
 }
 
-//--------------------------------------------------------------------------
 IMPLEMENT_GET_IMPLEMENTATION_ID( OTableColumn )
 
-//------------------------------------------------------------------------------
 rtl::OUString OTableColumn::getImplementationName(  ) throw (RuntimeException)
 {
-    return rtl::OUString::createFromAscii("com.sun.star.sdb.OTableColumn");
+    return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.sdb.OTableColumn"));
 }
 
-//------------------------------------------------------------------------------
 ::cppu::IPropertyArrayHelper& SAL_CALL OTableColumn::getInfoHelper()
 {
     return *OTableColumn_PBase::getArrayHelper();
 }
 
-//------------------------------------------------------------------------------
 ::cppu::IPropertyArrayHelper* OTableColumn::createArrayHelper( ) const
 {
     return OTableColumnDescriptor::createArrayHelper();
@@ -188,7 +176,6 @@ rtl::OUString OTableColumn::getImplementationName(  ) throw (RuntimeException)
 // =========================================================================
 DBG_NAME( OQueryColumn );
 
-// -------------------------------------------------------------------------
 OQueryColumn::OQueryColumn( const Reference< XPropertySet >& _rxParserColumn, const Reference< XConnection >& _rxConnection,const ::rtl::OUString i_sLabel )
     :OTableColumnDescriptor( false /* do not act as descriptor */ )
     ,m_sLabel(i_sLabel)
@@ -210,7 +197,7 @@ OQueryColumn::OQueryColumn( const Reference< XPropertySet >& _rxParserColumn, co
     OSL_VERIFY( _rxParserColumn->getPropertyValue( PROPERTY_ISAUTOINCREMENT ) >>= m_bAutoIncrement );
     OSL_VERIFY( _rxParserColumn->getPropertyValue( PROPERTY_ISCURRENCY ) >>= m_bCurrency );
     OSL_VERIFY( _rxParserColumn->getPropertyValue( PROPERTY_NAME ) >>= m_sName );
-    
+
     m_bRowVersion = sal_False;
 
     Reference< XPropertySetInfo > xPSI( _rxParserColumn->getPropertySetInfo(), UNO_SET_THROW );
@@ -230,7 +217,7 @@ OQueryColumn::OQueryColumn( const Reference< XPropertySet >& _rxParserColumn, co
         { PROPERTY_TABLENAME,        PROPERTY_ID_TABLENAME },
         { PROPERTY_REALNAME,         PROPERTY_ID_REALNAME }
     };
-    for ( size_t i=0; i < sizeof( aProps ) / sizeof( aProps[0] ); ++i )
+    for ( size_t i=0; i < SAL_N_ELEMENTS( aProps ); ++i )
     {
         if ( xPSI->hasPropertyByName( aProps[i].sName ) )
             setFastPropertyValue_NoBroadcast( aProps[i].nHandle, _rxParserColumn->getPropertyValue( aProps[i].sName ) );
@@ -244,13 +231,11 @@ OQueryColumn::OQueryColumn( const Reference< XPropertySet >& _rxParserColumn, co
     osl_decrementInterlockedCount( &m_refCount );
 }
 
-//--------------------------------------------------------------------------
 OQueryColumn::~OQueryColumn()
 {
     DBG_DTOR( OQueryColumn, NULL );
 }
 
-//--------------------------------------------------------------------------
 Reference< XPropertySet > OQueryColumn::impl_determineOriginalTableColumn( const Reference< XConnection >& _rxConnection )
 {
     OSL_PRECOND( _rxConnection.is(), "OQueryColumn::impl_determineOriginalTableColumn: illegal connection!" );
@@ -295,28 +280,23 @@ Reference< XPropertySet > OQueryColumn::impl_determineOriginalTableColumn( const
     return xOriginalTableColumn;
 }
 
-//--------------------------------------------------------------------------
 IMPLEMENT_GET_IMPLEMENTATION_ID( OQueryColumn )
 
-//--------------------------------------------------------------------------
 ::rtl::OUString SAL_CALL OQueryColumn::getImplementationName(  ) throw(RuntimeException)
 {
     return ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "org.openoffice.comp.dbaccess.OQueryColumn" ) );
 }
 
-//------------------------------------------------------------------------------
 ::cppu::IPropertyArrayHelper& SAL_CALL OQueryColumn::getInfoHelper()
 {
     return *OQueryColumn_PBase::getArrayHelper();
 }
 
-//--------------------------------------------------------------------------
 ::cppu::IPropertyArrayHelper* OQueryColumn::createArrayHelper() const
 {
     return OTableColumnDescriptor::createArrayHelper();
 }
 
-//--------------------------------------------------------------------------
 void SAL_CALL OQueryColumn::getFastPropertyValue( Any& _rValue, sal_Int32 _nHandle ) const
 {
     OTableColumnDescriptor::getFastPropertyValue( _rValue, _nHandle );
@@ -353,7 +333,7 @@ void SAL_CALL OQueryColumn::getFastPropertyValue( Any& _rValue, sal_Int32 _nHand
 //= OColumnWrapper
 //==========================================================================
 DBG_NAME(OColumnWrapper);
-//--------------------------------------------------------------------------
+
 OColumnWrapper::OColumnWrapper( const Reference< XPropertySet > & rCol, const bool _bNameIsReadOnly )
     :OColumn( _bNameIsReadOnly )
     ,m_xAggregate(rCol)
@@ -374,13 +354,12 @@ OColumnWrapper::OColumnWrapper( const Reference< XPropertySet > & rCol, const bo
         m_xAggregate->getPropertyValue(PROPERTY_NAME) >>= m_sName;
     }
 }
-// -----------------------------------------------------------------------------
+
 OColumnWrapper::~OColumnWrapper()
 {
     DBG_DTOR(OColumnWrapper,NULL);
 }
 
-//------------------------------------------------------------------------------
 ::rtl::OUString OColumnWrapper::impl_getPropertyNameFromHandle( const sal_Int32 _nHandle ) const
 {
     ::rtl::OUString sPropName;
@@ -390,7 +369,6 @@ OColumnWrapper::~OColumnWrapper()
     return sPropName;
 }
 
-//------------------------------------------------------------------------------
 void OColumnWrapper::getFastPropertyValue( Any& rValue, sal_Int32 nHandle ) const
 {
     // derived classes are free to either use the OPropertyContainer(Helper) mechanisms for properties,
@@ -406,7 +384,6 @@ void OColumnWrapper::getFastPropertyValue( Any& rValue, sal_Int32 nHandle ) cons
     }
 }
 
-//------------------------------------------------------------------------------
 sal_Bool OColumnWrapper::convertFastPropertyValue( Any & rConvertedValue, Any & rOldValue, sal_Int32 nHandle,
             const Any& rValue ) throw (IllegalArgumentException)
 {
@@ -427,7 +404,6 @@ sal_Bool OColumnWrapper::convertFastPropertyValue( Any & rConvertedValue, Any &
     return bModified;
 }
 
-//------------------------------------------------------------------------------
 void OColumnWrapper::setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, const Any& rValue ) throw (Exception)
 {
     if ( OColumn::isRegisteredProperty( nHandle ) )
@@ -440,7 +416,6 @@ void OColumnWrapper::setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, const
     }
 }
 
-// -----------------------------------------------------------------------------
 sal_Int64 SAL_CALL OColumnWrapper::getSomething( const Sequence< sal_Int8 >& aIdentifier ) throw(RuntimeException)
 {
     Reference< XUnoTunnel > xTunnel( m_xAggregate, UNO_QUERY);
@@ -452,7 +427,6 @@ sal_Int64 SAL_CALL OColumnWrapper::getSomething( const Sequence< sal_Int8 >& aId
 //============================================================
 //= OTableColumnDescriptorWrapper
 //============================================================
-//--------------------------------------------------------------------------
 OTableColumnDescriptorWrapper::OTableColumnDescriptorWrapper( const Reference< XPropertySet >& _rCol, const bool _bPureWrap, const bool _bIsDescriptor )
     :OColumnWrapper( _rCol, !_bIsDescriptor )
     ,m_bPureWrap( _bPureWrap )
@@ -463,17 +437,14 @@ OTableColumnDescriptorWrapper::OTableColumnDescriptorWrapper( const Reference< X
 }
 
 // com::sun::star::lang::XTypeProvider
-//--------------------------------------------------------------------------
 IMPLEMENT_GET_IMPLEMENTATION_ID( OTableColumnDescriptorWrapper )
 
 // ::com::sun::star::lang::XServiceInfo
-//------------------------------------------------------------------------------
 rtl::OUString OTableColumnDescriptorWrapper::getImplementationName(  ) throw (RuntimeException)
 {
-    return rtl::OUString::createFromAscii("com.sun.star.sdb.OTableColumnDescriptorWrapper");
+    return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.sdb.OTableColumnDescriptorWrapper"));
 }
 
-//------------------------------------------------------------------------------
 Sequence< ::rtl::OUString > OTableColumnDescriptorWrapper::getSupportedServiceNames(  ) throw (RuntimeException)
 {
     Sequence< ::rtl::OUString > aSNS( 2 );
@@ -483,7 +454,6 @@ Sequence< ::rtl::OUString > OTableColumnDescriptorWrapper::getSupportedServiceNa
 }
 
 // comphelper::OPropertyArrayUsageHelper
-//------------------------------------------------------------------------------
 ::cppu::IPropertyArrayHelper* OTableColumnDescriptorWrapper::createArrayHelper( sal_Int32 nId ) const
 {
     const sal_Int32 nHaveAlways = 7;
@@ -499,10 +469,7 @@ Sequence< ::rtl::OUString > OTableColumnDescriptorWrapper::getSupportedServiceNa
     if ( nId & HAS_AUTOINCREMENT_CREATION )
         ++nHaveOptionally;
 
-    const sal_Int32 nPropertyCount( nHaveAlways + nHaveOptionally );
-    Sequence< Property > aTableDescProperties( nPropertyCount );
-    Property* pDesc = aTableDescProperties.getArray();
-    sal_Int32 nPos = 0;
+    BEGIN_PROPERTY_SEQUENCE( nHaveAlways + nHaveOptionally )
 
     DECL_PROP0_BOOL( ISAUTOINCREMENT                );
     DECL_PROP0_BOOL( ISCURRENCY                     );
@@ -529,12 +496,12 @@ Sequence< ::rtl::OUString > OTableColumnDescriptorWrapper::getSupportedServiceNa
         DECL_PROP0_BOOL( ISROWVERSION );
     }
 
-    OSL_ENSURE( nPos == nPropertyCount, "OTableColumnDescriptorWrapper::createArrayHelper: something went wrong!" );
+    END_PROPERTY_SEQUENCE()
 
     if ( !m_bIsDescriptor )
     {
-        for (   Property* prop = aTableDescProperties.getArray();
-                prop != aTableDescProperties.getArray() + aTableDescProperties.getLength();
+        for (   Property* prop = aDescriptor.getArray();
+                prop != aDescriptor.getArray() + aDescriptor.getLength();
                 ++prop
             )
         {
@@ -546,18 +513,16 @@ Sequence< ::rtl::OUString > OTableColumnDescriptorWrapper::getSupportedServiceNa
     Sequence< Property > aBaseProperties;
     describeProperties( aBaseProperties );
 
-    Sequence< Property > aAllProperties( ::comphelper::concatSequences( aTableDescProperties, aBaseProperties ) );
+    Sequence< Property > aAllProperties( ::comphelper::concatSequences( aDescriptor, aBaseProperties ) );
     return new ::cppu::OPropertyArrayHelper( aAllProperties, sal_False );
 }
 
 // cppu::OPropertySetHelper
-//------------------------------------------------------------------------------
 ::cppu::IPropertyArrayHelper& OTableColumnDescriptorWrapper::getInfoHelper()
 {
     return *static_cast< OIdPropertyArrayUsageHelper< OTableColumnDescriptorWrapper >* >(this)->getArrayHelper(m_nColTypeID);
 }
 
-//------------------------------------------------------------------------------
 void OTableColumnDescriptorWrapper::getFastPropertyValue( Any& rValue, sal_Int32 nHandle ) const
 {
     if ( m_bPureWrap )
@@ -570,7 +535,6 @@ void OTableColumnDescriptorWrapper::getFastPropertyValue( Any& rValue, sal_Int32
     }
 }
 
-//------------------------------------------------------------------------------
 sal_Bool OTableColumnDescriptorWrapper::convertFastPropertyValue( Any & rConvertedValue, Any & rOldValue, sal_Int32 nHandle, const Any& rValue ) throw (IllegalArgumentException)
 {
     sal_Bool bModified(sal_False);
@@ -595,7 +559,6 @@ sal_Bool OTableColumnDescriptorWrapper::convertFastPropertyValue( Any & rConvert
     return bModified;
 }
 
-//------------------------------------------------------------------------------
 void OTableColumnDescriptorWrapper::setFastPropertyValue_NoBroadcast(
                                                 sal_Int32 nHandle,
                                                 const Any& rValue
@@ -615,7 +578,6 @@ void OTableColumnDescriptorWrapper::setFastPropertyValue_NoBroadcast(
 //============================================================
 //= OTableColumnWrapper
 //============================================================
-//--------------------------------------------------------------------------
 OTableColumnWrapper::OTableColumnWrapper( const Reference< XPropertySet >& rCol, const Reference< XPropertySet >& _xColDefintion,
             const bool _bPureWrap )
     :OTableColumnDescriptorWrapper( rCol, _bPureWrap, false )
@@ -635,21 +597,17 @@ OTableColumnWrapper::OTableColumnWrapper( const Reference< XPropertySet >& rCol,
     osl_decrementInterlockedCount( &m_refCount );
 }
 
-//--------------------------------------------------------------------------
 OTableColumnWrapper::~OTableColumnWrapper()
 {
 }
 
-//--------------------------------------------------------------------------
 IMPLEMENT_GET_IMPLEMENTATION_ID( OTableColumnWrapper )
 
-//------------------------------------------------------------------------------
 rtl::OUString OTableColumnWrapper::getImplementationName(  ) throw (RuntimeException)
 {
-    return rtl::OUString::createFromAscii( "com.sun.star.sdb.OTableColumnWrapper" );
+    return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(  "com.sun.star.sdb.OTableColumnWrapper" ));
 }
 
-//------------------------------------------------------------------------------
 Sequence< ::rtl::OUString > OTableColumnWrapper::getSupportedServiceNames(  ) throw (RuntimeException)
 {
     Sequence< ::rtl::OUString > aSNS( 2 );
@@ -658,16 +616,14 @@ Sequence< ::rtl::OUString > OTableColumnWrapper::getSupportedServiceNames(  ) th
     return aSNS;
 }
 
-//------------------------------------------------------------------------------
 ::cppu::IPropertyArrayHelper& OTableColumnWrapper::getInfoHelper()
 {
     return *static_cast< OIdPropertyArrayUsageHelper< OTableColumnWrapper >* >(this)->getArrayHelper(m_nColTypeID);
 }
 
 // comphelper::OPropertyArrayUsageHelper
-//------------------------------------------------------------------------------
 ::cppu::IPropertyArrayHelper* OTableColumnWrapper::createArrayHelper( sal_Int32 nId ) const
 {
     return OTableColumnDescriptorWrapper::createArrayHelper( nId );
 }
-
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
